-- $Id: device_port_ssid.sql,v 1.3 2009/04/13 01:00:27 olly_g Exp $

DROP TABLE device_port_ssid;

CREATE TABLE device_port_ssid (
    ip          inet,   -- ip of device
    port        text,   -- Unique identifier of Physical Port Name
    ssid        text,   -- An SSID that is valid on this port.
    broadcast   boolean -- Is it broadcast?
);

CREATE INDEX idx_device_port_ssid_ip_port ON device_port_ssid(ip,port);
